Create a curve set out of a list in the right form.
create_curve_set(curve_set, ...)A list containing elements r, obs, and optionally
the elements sim_m and theo.
r must be a vector describing the radius vector, the argument values where
functions have been observed (or simulated).
obs must be either 1) a vector containing the data function, in which case
obs must have same length as r, or
2) a matrix containing the s data functions, in which case it is assumed that
each column corresponds to a data function, and the number of rows must match the length or r.
If obs is a vector, sim_m must be a matrix containing the simulated functions.
Each column is assumed to correspond to a function, and the number of rows must match the
length of r. If obs is a matrix, sim_m is ignored.
If included, theo corresponds to the theoretical function (e.g., under the null hypothesis).
If present, its length must match the length of r.
Do not use. (For internal use only.)
The given list adorned with the proper class name.