Learn R Programming

GET (version 0.1-3)

graph.fanova2d: One-way graphical functional ANOVA for images

Description

One-way ANOVA tests for image data with graphical interpretation

Usage

graph.fanova2d(nsim, image_set, groups, ...)

Arguments

nsim

The number of random permutations.

image_set

A set of images containing the data, see create_image_set.

groups

The original groups (a factor vector representing the assignment to groups).

...

Additional parameters to be passed to graph.fanova.

Value

A global_envelope2d or combined_global_envelope2d object, which can be printed and plotted directly.

Details

This function can be used to perform one-way graphical functional ANOVA tests described in Mrkvi<U+010D>ka et al. (2018). The function transforms images to vectors (1d), calls graph.fanova and transform results back to images (2d).

References

Mrkvi<U+010D>ka, T., Myllym<U+00E4>ki, M., Jilek, M. and Hahn, U. (2018) A one-way ANOVA test for functional data with graphical interpretation. arXiv:1612.03608 [stat.ME] (http://arxiv.org/abs/1612.03608)

Examples

Run this code
# NOT RUN {
data("imageset1")
res <- graph.fanova2d(nsim = 19, # Increase nsim for serious analysis!
                      image_set = imageset1$image_set,
                      groups = imageset1$Group)
plot(res)
# Contrasts
res.c <- graph.fanova2d(nsim = 19, # Increase nsim for serious analysis!
                        image_set = imageset1$image_set,
                        groups = imageset1$Group,
                        summaryfun = "contrasts")
plot(res.c)
plot(res.c, contours=FALSE)
# }

Run the code above in your browser using DataLab