Learn R Programming

GET (version 0.1-3)

imageset2: A simulated set of images

Description

A simulated set of images with two simulated covariates

Usage

data(imageset2)

Arguments

Format

A list of the image_set containing the simulated images, the discrete group factor in the list component Group, and the continuous factor z in the list component z.

Details

We considered a categorical factor Group obtaining the values 0 or 1 according to the group to which the image belongs to (10 images in the first group, 10 images in the second), and a continous factor z that was generated from the uniform distribution on (0,1). The images were simulated in the square window [-1,1]^2 from the general linear model (GLM) $$Y(r) = \exp(-10\cdot ||r||) \cdot (1 + g + z) + \epsilon(r),$$ where ||r|| denotes the Euclidean distance of the pixel to the origin, g is the group and the error stems from an inhomogeneous distribution over $I$ with the normal and bimodal errors in the middle and periphery of the image: $$\epsilon(r) = \mathbf{1}(\|r\| \leq 0.5) G(r) + \mathbf{1}(\|r\| > 0.5) \frac{1}{2}G(r)^{1/5},$$ where G(r) is a Gaussian random field with the exponential correlation structure with scale parameter 0.15 and standard deviation 0.2.

References

Mrkvi<U+010D>ka, T., Myllym<U+00E4>ki, M. and Narisetty, N. N. (2019) New methods for multiple testing in permutation inference for the general linear model. arXiv:1906.09004 [stat.ME]

See Also

graph.fglm2d, frank.fglm2d

Examples

Run this code
# NOT RUN {
data(imageset2)
plot(imageset2$image_set, idx=c(1:5, 11:15), max_ncols_of_plots=5)
# }

Run the code above in your browser using DataLab