Learn R Programming

GET (version 0.1-6)

imageset3: A simulated set of images

Description

A simulated set of images with a categorical factor

Usage

data(imageset3)

Arguments

Format

A list of the image_set containing the simulated images, and the discrete group factor in the list component Group.

Details

We considered a categorical factor Group obtaining the values 0, 1 or 2 according to the group to which the image belongs to (10 images in each of the three groups). The images were simulated in the square window [-1,1]^2 from the general linear model (GLM) $$Y(r) = \exp(-10\cdot ||r||) \cdot (1 + \mathbf{1}(g=2)) + \epsilon(r),$$ where ||r|| denotes the Euclidean distance of the pixel to the origin, g is the group and the error stems from an inhomogeneous distribution over $I$ with the normal and bimodal errors in the middle and periphery of the image: $$\epsilon(r) = \mathbf{1}(\|r\| \leq 0.5) G(r) + \mathbf{1}(\|r\| > 0.5) \frac{1}{2}G(r)^{1/5},$$ where G(r) is a Gaussian random field with the exponential correlation structure with scale parameter 0.15 and standard deviation 0.2.

References

Mrkvi<U+010D>ka, T., Myllym<U+00E4>ki, M. and Narisetty, N. N. (2019) New methods for multiple testing in permutation inference for the general linear model. arXiv:1906.09004 [stat.ME]

See Also

graph.fanova2d, frank.fanova2d

Examples

Run this code
# NOT RUN {
data(imageset3)
plot(imageset3$image_set, idx=c(1:5, 11:15, 21:25), max_ncols_of_plots = 5)
# }

Run the code above in your browser using DataLab