Learn R Programming

GET (version 0.1-3)

plot.combined_fboxplot: Plot method for the class 'combined_fboxplot'

Description

Plot method for the class 'combined_fboxplot'

Usage

# S3 method for combined_fboxplot
plot(x, plot_style = c("ggplot2", "fv",
  "basic"), level = 1, outliers = TRUE, bp.col = 2, cr.col = 1,
  ...)

Arguments

x

an 'combined_fboxplot' object

plot_style

One of the following "basic", "fv" or "ggplot2". The option "basic" (default) offers a very basic global envelope plot. The option "fv" utilizes the plot routines of the function value table fv.object. For "ggplot2", a plot with a coloured envelope ribbon is provided. Requires R library ggplot2. The option "fv" is currently only available for tests with one test function, whereas the other true allow also tests with several tests functions.

level

1 or 2. In the case of two-step combined tests (with several test functions), two different plots are available: 1 for plotting the combined global envelopes (default and most often wanted) or 2 for plotting the second level test result.

outliers

Logical. If TRUE, then the functions outside the functional boxplot are drawn.

bp.col

The color for the boxplot bounds. Default 2 (red).

cr.col

The color for the central region bounds.

...

Additional arguments to be passed to plot.combined_global_envelope.