Learn R Programming

GET (version 0.1-8)

plot.curve_set: Plot method for the class 'curve_set'

Description

Plot method for the class 'curve_set'

Usage

# S3 method for curve_set
plot(
  x,
  plot_style = c("ggplot2", "basic"),
  ylim,
  xlab = "r",
  ylab = "obs",
  main = NULL,
  col_obs = 1,
  col_sim = "grey70",
  base_size = 11,
  ...
)

Arguments

x

An curve_set object

plot_style

Either "ggplot2" or "basic".

ylim

The y limits of the plot with the default being the minimum and maximum over all curves.

xlab

The label for the x-axis. Default "r".

ylab

The label for the y-axis. Default "obs".

main

See plot.default. A sensible default exists.

col_obs

Color for 'obs' in the argument x.

col_sim

Color for 'sim_m' in the argument x.

base_size

Base font size, to be passed to theme style when plot_style = "ggplot2".

...

Additional parameters to be passed to plot and lines.