Base font size, to be passed to theme style when plot_style = "ggplot2".
ncol
The maximum number of columns for the figures.
Default 2 or 3, if the length of x equals 3.
(Relates to the number of curve_sets that have been combined.)
...
Additional parameters to be passed to plot and lines.