Learn R Programming

GET (version 0.1-8)

plot.fboxplot: Plot method for the class 'fboxplot'

Description

Plot method for the class 'fboxplot'

Usage

# S3 method for fboxplot
plot(
  x,
  plot_style = c("ggplot2", "basic"),
  dotplot = length(x$r) < 10,
  outliers = TRUE,
  bp.col = 2,
  cr.col = 1,
  ...
)

Arguments

x

an 'fboxplot' object

plot_style

One of the following "ggplot2" or "basic" or "fv". For "ggplot2", a plot with a coloured envelope ribbon is provided. Requires R library ggplot2. The option "basic" (default) offers a very basic plot. The option "fv" utilizes the plot routines of the function value table fv.object, available only for spatstat-specific cases.

dotplot

Logical. If TRUE, then instead of envelopes a dot plot is done. Suitable for low dimensional test vectors. Default: TRUE if the dimension is less than 10, FALSE otherwise.

outliers

Logical. If TRUE, then the functions outside the functional boxplot are drawn, together with a label (= index in the set of functions).

bp.col

The color for the boxplot bounds. Default 2 (red).

cr.col

The color for the central region bounds.

...

Additional arguments to be passed to plot.global_envelope.