Learn R Programming

GET (version 0.1-8)

plot.global_envelope: Plot method for the class 'global_envelope'

Description

Plot method for the class 'global_envelope'

Usage

# S3 method for global_envelope
plot(
  x,
  plot_style = c("ggplot2", "fv", "basic"),
  dotplot = length(x$r) < 10,
  main,
  ylim,
  xlab,
  ylab,
  env.col = 1,
  color_outside = TRUE,
  sign.col = "red",
  base_size = 11,
  labels = NULL,
  add = FALSE,
  digits = 3,
  legend = TRUE,
  ...
)

Arguments

x

An 'global_envelope' object

plot_style

One of the following "ggplot2" or "basic" or "fv". For "ggplot2", a plot with a coloured envelope ribbon is provided. Requires R library ggplot2. The option "basic" (default) offers a very basic plot. The option "fv" utilizes the plot routines of the function value table fv.object, available only for spatstat-specific cases.

dotplot

Logical. If TRUE, then instead of envelopes a dot plot is done. Suitable for low dimensional test vectors. Default: TRUE if the dimension is less than 10, FALSE otherwise.

main

See plot.default. A sensible default exists.

ylim

See plot.default. A sensible default exists.

xlab

See plot.default. A sensible default exists.

ylab

See plot.default. A sensible default exists.

env.col

The color for the envelope lines (or dotplot arrows) for 1d functions. Default 1 (black).

color_outside

Logical. Whether to color the places where the data function goes outside the envelope. Relevant only for 1d functions.

sign.col

The color for the significant regions. Default to "red".

base_size

Base font size, to be passed to theme style when plot_style = "ggplot2".

labels

A character vector of suitable length. If dotplot = TRUE, then labels for the tests at x-axis.

add

Whether to add the plot to an existing plot (TRUE) or to draw a new plot (FALSE). Not available for plot_style = "ggplot2".

digits

The number of digits used for printing the p-value or p-interval in the main, if using the default main.

legend

Logical. If FALSE, then the legend is removed from the "ggplot2" style plot.

...

Additional parameters to be passed to plot or lines.

See Also

central_region, global_envelope_test