Learn R Programming

GET (version 0.1-5)

plot.global_envelope2d: Plot method for the class 'global_envelope2d'

Description

Plot method for the class 'global_envelope2d'

Usage

# S3 method for global_envelope2d
plot(
  x,
  plot_style = c("ggplot2", "basic"),
  fixedscales = TRUE,
  sign.col = "red",
  transparency = 85/255,
  contours = FALSE,
  main = NULL,
  digits = 3,
  ...
)

Arguments

x

an 'global_envelope2d' object

plot_style

Either "ggplot2" or "basic". (Similar to the argument in plot.global_envelope.)

fixedscales

Logical. TRUE for the same scales for all images.

sign.col

The color for the significant regions. Default to "red".

transparency

A number between 0 and 1 (default 85/255, 33 Similar to alpha of rgb. Used in plotting the significant regions.

contours

Logical. Whether to draw contour lines to the observed function and the lower and upper envelope.

main

The overall main. Default exists.

digits

The number of digits used for printing the p-value or p-interval in the main, if using the default main.

...

Additional parameters to be passed to plot.im.

Details

Additional parameter col can be passed in ... to plot.im. If col not given, a colourmap of 255 grey values between the minimum and maximum of the function values is used for each image separately. If col is provided, the same specification will be used for each produced plot, which may make it easier to compare the figures with each other.