Learn R Programming

GET (version 0.1-5)

rimov: Year temperature curves

Description

Year temperature curves

Usage

data(rimov)

Arguments

Format

A curve_set object with water temperatures in 365 days of the 36 years. The component curve_set[['r']] is a vector of days (from 1 to 365), whereas curve_set[['obs']] contains the water temperatures such that each column gives year temperatures in a year.

Details

The water temperature data sampled at the water level of Rimov reservoir in Czech republic every day for the 36 years between 1979 and 2014.

References

Mrkvi<U+010D>ka, T., Hahn, U. and Myllym<U+00E4>ki, M. (2018) A one-way ANOVA test for functional data with graphical interpretation. arXiv:1612.03608v2 [stat.ME] (http://arxiv.org/abs/1612.03608v2)

See Also

graph.fanova

Examples

Run this code
# NOT RUN {
data(rimov)
groups <- factor(c(rep(1, times=12), rep(2, times=12), rep(3, times=12)))
# Plot data in groups
subs <- function(group, ...) {
  cset <- rimov
  cset$obs <- rimov$obs[, groups == group]
  plot(cset, ...)
}
for(i in 1:3) subs(i, main=paste("group ", i, sep=""), ylab="Temperature")
# See example analysis in ?graph.fanova
# }

Run the code above in your browser using DataLab