The function is used to clump together the functional data in the form
that can be handled by the other GET functions (forder,
central_region, global_envelope_test etc.).
The function create_curve_set takes care of checking the content of
the data, and saves relevant information of the curves for global envelope
methods to be used in particular for plotting the results with graphical
interpretation.
obs must be either
a vector containing the data function/vector, or
a matrix containing the s data functions/vectors, in which case it is assumed that
each column corresponds to a data function/vector.
If given, r describes the 1- or 2-dimensional argument values where the functions/vectors
have been observed (or simulated). It must be either
a vector,
a data.frame with columns "x", "y", "width" and "height",
where the width and height give the width and height of the pixels placed at x and y, or
a data.frame with columns "xmin", "xmax", "ymin" and "ymax" giving the corner
coordinates of the pixels where the data have been observed.
If obs is a vector, sim_m must be a matrix containing the simulated functions.
Each column is assumed to correspond to a function, and the number of rows must match the
length of obs. If obs is a matrix, sim_m is ignored.
If obs is a vector, theo can be given and it should then correspond
to a theoretical function (e.g., under the null hypothesis). If present, its length must match the length of
obs.