Crop the curves to a certain interval in preparation for a deviation test.
crop_curves(curve_set, r_min = NULL, r_max = NULL)A curve_set (see create_curve_set) or
an envelope object. If an envelope object is given,
it must contain the summary functions from the simulated patterns which can be
achieved by setting savefuns = TRUE when calling envelope.
The minimum radius to include.
The maximum radius to include.
A curve_set object containing the cropped summary functions and the cropped radius vector.