Plot method for the class 'combined_global_envelope2d'
# S3 method for combined_global_envelope2d
plot(x, plot_style = c("ggplot2",
"basic"), fixedscales = 2, sign.col = "red", transparency = 85/255,
contours = FALSE, main = NULL, digits = 3, ...)an 'combined_global_envelope2d' object
Either "ggplot2" or "basic". (Similar to the argument in plot.global_envelope.)
0, 1 or 2. See details.
The color for the significant regions. Default to "red".
A number between 0 and 1 (default 85/255, 33
Similar to alpha of rgb. Used in plotting the significant regions.
Logical. Whether to draw contour lines to the observed function and the lower and upper envelope.
The overall main. Default exists.
The number of digits used for printing the p-value or p-interval in the main, if using the default main.
Additional parameters to be passed to plot.im.
Additional parameter col can be passed in ... to plot.im.
If col not given, a colourmap of 255 grey values between the
minimum and maximum of the function values is used for each image separately.
If col is provided, the same specification will be used for each produced plot,
which may make it easier to compare the figures with each other.
If fixedscales is FALSE (or 0) all images will have separate scale. If fixedscales is TRUE (or 1) each x[[i]] will have a common scale. If fixedscales is 2 all images will have common scale.