Learn R Programming

GET (version 0.2)

plot.combined_global_envelope2d: Plotting function for combined 2d global envelopes

Description

If fixedscales is FALSE (or 0) all images will have separate scale. If fixedscales is TRUE (or 1) each x[[i]] will have a common scale. If fixedscales is 2 all images will have common scale.

Usage

# S3 method for combined_global_envelope2d
plot(
  x,
  fixedscales = 2,
  main,
  what = c("obs", "lo", "hi", "lo.sign", "hi.sign"),
  sign.col = "red",
  transparency = 155/255,
  digits = 3,
  base_size = 11,
  ...
)

Arguments

x

A 'global_envelope' object for two-dimensional functions

fixedscales

0, 1 or 2. See details.

main

The overall main.

what

Character vector specifying what information should be plotted for 2d functions. A combination of: Observed ("obs"), upper envelope ("hi"), lower envelope ("lo"), observed with significantly higher values highlighted ("hi.sign"), observed with significantly lower values highlighted ("lo.sign").

sign.col

The color for the significant regions. Default to "red".

transparency

A number between 0 and 1 (default 155/255, 60 Similar to alpha of rgb. Used in plotting the significant regions for 2d functions.

digits

The number of digits used for printing the p-value or p-interval in the main, if using the default main.

base_size

Base font size, to be passed to theme style when plot_style = "ggplot2".

...

Ignored.

Examples

Run this code
# NOT RUN {
data(abide_9002_23)

res <- graph.flm(nsim = 19, # Increase nsim for serious analysis!
                 formula.full = Y ~ Group + Sex + Age,
                 formula.reduced = Y ~ Sex + Age,
                 curve_sets = list(Y = subset(abide_9002_23[['curve_set']], 1:50)),
                 factors = abide_9002_23[['factors']][1:50,],
                 contrasts = FALSE,
                 GET.args = list(type = "area"))
plot(res)
plot(res, what=c("obs", "hi"))

plot(res, what=c("hi", "lo"), fixedscales=1)

plot(res, what=c("obs", "lo", "hi"), fixedscales=FALSE)

if(requireNamespace("gridExtra", quietly=TRUE) && require("ggplot2", quietly=TRUE)) {
  # Edit style of "fixedscales = 2" plots
  plot(res, what=c("obs", "hi")) + theme_minimal()

  # Edit style (e.g. theme) of "fixedscales = 1 or 0" plots
  gs <- lapply(res, plot, what=c("obs", "hi"), main="")
  gridExtra::grid.arrange(grobs=gs, ncol=1, top="My main")

  gs <- outer(res, c("obs", "hi"), FUN=Vectorize(function(res, what)
    list(plot(res, what=what, main="") + theme(axis.ticks=element_blank(),
      axis.text=element_blank(), axis.title=element_blank()))))
  gridExtra::grid.arrange(grobs=t(gs))
}
# }

Run the code above in your browser using DataLab