Learn R Programming

GET (version 0.1-3)

plot.curve_set: Plot method for the class 'curve_set'

Description

Plot method for the class 'curve_set'

Usage

# S3 method for curve_set
plot(x, ylim, xlab = "r", ylab = "obs",
  col_obs = 1, col_sim = grDevices::grey(0.7), ...)

Arguments

x

An curve_set object

ylim

The y limits of the plot with the default being the minimum and maximum over all curves.

xlab

The label for the x-axis. Default "r".

ylab

The label for the y-axis. Default "obs".

col_obs

Color for 'obs' in the argument x.

col_sim

Color for 'sim_m' in the argument x.

...

Additional parameters to be passed to plot and lines.