Plot method for the class 'curve_set'
# S3 method for curve_set
plot(x, ylim, xlab = "r", ylab = "obs",
col_obs = 1, col_sim = grDevices::grey(0.7), ...)An curve_set object
The y limits of the plot with the default being the minimum and maximum over all curves.
The label for the x-axis. Default "r".
The label for the y-axis. Default "obs".
Color for 'obs' in the argument x.
Color for 'sim_m' in the argument x.
Additional parameters to be passed to plot and lines.