Plot method for the class 'curve_set'
# S3 method for curve_set
plot(
x,
plot_style = c("ggplot2", "basic"),
ylim,
xlab = "r",
ylab = "obs",
main = NULL,
col_obs = 1,
col_sim = "grey70",
base_size = 11,
...
)An curve_set object
Either "ggplot2" or "basic".
The y limits of the plot with the default being the minimum and maximum over all curves.
The label for the x-axis. Default "r".
The label for the y-axis. Default "obs".
See plot.default. A sensible default exists.
Color for 'obs' in the argument x.
Color for 'sim_m' in the argument x.
Base font size, to be passed to theme style when plot_style = "ggplot2".
Additional parameters to be passed to plot and lines.