Learn R Programming

GET (version 0.2)

plot.curve_set2d: Plot method for the class 'curve_set2d'

Description

Plot method for the class 'curve_set2d', i.e. two-dimensional functions

Usage

# S3 method for curve_set2d
plot(x, idx = 1, base_size = 11, ncol = 2 + 1 * (length(idx) == 3), ...)

Arguments

x

An curve_set2d object

idx

Indices of functions to plot for 2d plots.

base_size

Base font size, to be passed to theme style when plot_style = "ggplot2".

ncol

The maximum number of columns for the figures. Default 2 or 3, if the length of x equals 3. (Relates to the number of curve_sets that have been combined.)

...

Additional parameters to be passed to plot and lines.

Examples

Run this code
# NOT RUN {
data(abide_9002_23)
plot(abide_9002_23$curve_set, idx=c(1, 27))
# }

Run the code above in your browser using DataLab