Plot method for the class 'fboxplot'
# S3 method for fboxplot
plot(
x,
plot_style = c("ggplot2", "fv", "basic"),
dotplot = length(x$r) < 10,
outliers = TRUE,
bp.col = 2,
cr.col = 1,
...
)an 'fboxplot' object
One of the following "basic", "fv" or "ggplot2".
The option "basic" (default) offers a very basic global envelope plot.
The option "fv" utilizes the plot routines of the function value table fv.object.
For "ggplot2", a plot with a coloured envelope ribbon is provided. Requires R library ggplot2.
The option "fv" is currently only available for tests with one test function, whereas the other true allow
also tests with several tests functions.
Logical. If TRUE, then instead of envelopes a dot plot is done.
Suitable for low dimensional test vectors. Only applicable if plot_style is "basic".
Default: TRUE if the dimension is less than 10, FALSE otherwise.
Logical. If TRUE, then the functions outside the functional boxplot are drawn.
The color for the boxplot bounds. Default 2 (red).
The color for the central region bounds.
Additional arguments to be passed to plot.global_envelope.