Learn R Programming

GET (version 0.1-8)

plot.global_envelope2d: Plotting function for 2d global envelopes

Description

Plotting function for 2d global envelopes

Usage

# S3 method for global_envelope2d
plot(
  x,
  fixedscales = TRUE,
  main,
  what = c("obs", "lo", "hi", "lo.sign", "hi.sign"),
  sign.col = "red",
  transparency = 155/255,
  digits = 3,
  base_size = 11,
  ...
)

Arguments

x

A 'global_envelope' object for two-dimensional functions

fixedscales

Logical. TRUE for the same scales for all images.

main

The overall main.

what

Character vector specifying what information should be plotted for 2d functions. A combination of: Observed ("obs"), upper envelope ("hi"), lower envelope ("lo"), observed with significantly higher values highlighted ("hi.sign"), observed with significantly lower values highlighted ("lo.sign").

sign.col

The color for the significant regions. Default to "red".

transparency

A number between 0 and 1 (default 155/255, 60 Similar to alpha of rgb. Used in plotting the significant regions for 2d functions.

digits

The number of digits used for printing the p-value or p-interval in the main, if using the default main.

base_size

Base font size, to be passed to theme style when plot_style = "ggplot2".

...

Ignored.